
# Type: date


a date (year, month and day) in an idealized calendar

URI: [https://w3id.org/biolink/biolinkml/meta/biolinkml:types/Date](https://w3id.org/biolink/biolinkml/meta/biolinkml:types/Date)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **XSDDate** |
| Representation | | str |
